@@ -76,8 +76,8 @@ class ModuleFinder:
             excludes or []
         )
         self._bad_modules = {}
-        self._hooks = __import__("cx_Freeze", fromlist=["hooks"]).hooks
-        self._hooks.initialize(self)
+        for name in self._base_hooks.exclude.MODULES:
+            self.exclude_module(name)
         self._add_base_modules()
 
     def _add_base_modules(self) -> None:
@@ -143,6 +143,20 @@ class ModuleFinder:
             return self._get_parent_by_name(caller.name)
         return None
 
+    @cached_property
+    def _base_hooks(self):
+        """Load the hooks dynamically to avoid cyclic errors, because hooks
+        have references to finder."""
+        hooks = get_resource_file_path("hooks", "__init__", ".py")
+        fromlist = []
+        # add python files (modules)
+        for path in hooks.parent.glob("*.py"):
+            fromlist.append("hooks" if path.stem == "__init__" else path.stem)
+        # add directories (subpackages)
+        for path in hooks.parent.glob("*/__init__.py"):
+            fromlist.append(path.parent.stem)
+        return __import__("cx_Freeze.hooks", fromlist=fromlist)
+
     @cached_property
     def _builtin_modules(self) -> Set[str]:
         """The built-in modules are determined based on the cx_Freeze build."""
@@ -579,10 +593,21 @@ class ModuleFinder:
         )
 
     def _run_hook(self, hook: str, module_name: str, *args) -> None:
-        """Run hook (load or missing) for the given module if one is
-        present."""
+        """Run hook (load or missing) for the given module if one is present.
+        For functions present in hooks.__init__:
+        package aiofiles -> load_aiofiles function
+        For functions in a separated module (lowercased):
+        package PyQt5, module QtCore -> pyqt5.load_pyqt5_qtcore
+        """
+        base_hooks = self._base_hooks
         normalized_name = module_name.replace(".", "_")
-        method = getattr(self._hooks, f"{hook}_{normalized_name}", None)
+        method = getattr(base_hooks, f"{hook}_{normalized_name}", None)
+        if method is None:
+            root = module_name.split(".")[0].lower()
+            base_hooks = getattr(base_hooks, root, None)
+            if base_hooks is not None:
+                normalized_name = normalized_name.lower()
+                method = getattr(base_hooks, f"{hook}_{normalized_name}", None)
         if method is not None:
             method(self, *args)
 
@@ -723,6 +748,11 @@ class ModuleFinder:
             name = path.name.partition(".")[0]
         deferred_imports: DeferredList = []
         module = self._load_module_from_file(name, path, deferred_imports)
+        if module is not None:
+            parent = self._get_parent_by_name(name)
+            if parent is not None:
+                parent.global_names.add(module.name)
+                module.parent = parent
         self._import_deferred_imports(deferred_imports)
         return module
 
